"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    namespace: str,
    identity_store: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    (Enterprise edition only) Creates a new namespace for you to use with Amazon QuickSight. A namespace allows you to isolate the QuickSight users and groups that are registered for that namespace. Users that access the namespace can share assets only with other users or groups in the same namespace. They can't see users and groups in other namespaces. You can create a namespace after your Amazon Web Services account; is subscribed to QuickSight. The namespace must be unique within the Amazon Web Services account;. By default, there is a limit of 100 namespaces per Amazon Web Services account;. To increase your limit, create a ticket with Amazon Web Services Support.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to create the QuickSight namespace in.
        namespace(str): The name that you want to use to describe the new namespace.
        identity_store(str): Specifies the type of your user identity directory. Currently, this supports users with an identity type of QUICKSIGHT.
        tags(List, optional): The tags that you want to associate with the namespace that you're creating. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.namespace.create(
                ctx, aws_account_id=value, namespace=value, identity_store=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.namespace.create aws_account_id=value, namespace=value, identity_store=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_namespace",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
            "IdentityStore": identity_store,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, aws_account_id: str, namespace: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a namespace and the users and groups that are associated with the namespace. This is an asynchronous process. Assets including dashboards, analyses, datasets and data sources are not deleted. To delete these assets, you use the API operations for the relevant asset.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to delete the QuickSight namespace from.
        namespace(str): The namespace that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.namespace.delete(
                ctx, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.namespace.delete aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_namespace",
        op_kwargs={"AwsAccountId": aws_account_id, "Namespace": namespace},
    )


async def describe(hub, ctx, aws_account_id: str, namespace: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the current namespace.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that contains the QuickSight namespace that you want to describe.
        namespace(str): The namespace that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.namespace.describe(
                ctx, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.namespace.describe aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_namespace",
        op_kwargs={"AwsAccountId": aws_account_id, "Namespace": namespace},
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the namespaces for the specified Amazon Web Services account;.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that contains the QuickSight namespaces that you want to list.
        next_token(str, optional): A pagination token that can be used in a subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.namespace.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.namespace.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_namespaces",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    filter_: Dict,
    locale: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of entities that have been affected by the specified events, based on the specified filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the AWS service. Events that have impact beyond that of the affected entities, or where the extent of impact is unknown, include at least one entity indicating this. At least one event ARN is required. Results are sorted by the lastUpdatedTime of the entity, starting with the most recent.    This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.   This operation supports resource-level permissions. You can use this operation to allow or deny access to specific AWS Health events. For more information, see Resource- and action-based conditions in the AWS Health User Guide.

    Args:
        filter_(Dict): Values to narrow the results returned. At least one event ARN is required.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.affected.entity.init.describe_all(ctx, filter_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.affected.entity.init.describe_all filter_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_affected_entities",
        op_kwargs={
            "filter": filter_,
            "locale": locale,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified namespace. This action deletes all of the entities in the namespace. Delete the systems and flows that use entities in the namespace before performing this action.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.namespace.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.namespace.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iotthingsgraph", operation="delete_namespace", op_kwargs={}
    )


async def describe(hub, ctx, namespace_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the latest version of the user's namespace and the public version that it is tracking.

    Args:
        namespace_name(str, optional): The name of the user's namespace. Set this to aws to get the public namespace. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.namespace.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.namespace.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="describe_namespace",
        op_kwargs={"namespaceName": namespace_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    execution_role_arn: str,
    description: str,
    state: str,
    policy_details: Dict,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a policy to manage the lifecycle of the specified AWS resources. You can create up to 100 lifecycle policies.

    Args:
        execution_role_arn(str): The Amazon Resource Name (ARN) of the IAM role used to run the operations specified by the lifecycle policy.
        description(str): A description of the lifecycle policy. The characters ^[0-9A-Za-z _-]+$ are supported.
        state(str): The desired activation state of the lifecycle policy after creation.
        policy_details(Dict): The configuration details of the lifecycle policy.
        tags(Dict, optional): The tags to apply to the lifecycle policy during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dlm.lifecycle_policy.create(
                ctx, execution_role_arn=value, description=value, state=value, policy_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dlm.lifecycle_policy.create execution_role_arn=value, description=value, state=value, policy_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dlm",
        operation="create_lifecycle_policy",
        op_kwargs={
            "ExecutionRoleArn": execution_role_arn,
            "Description": description,
            "State": state,
            "PolicyDetails": policy_details,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, policy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified lifecycle policy and halts the automated operations that the policy specified.

    Args:
        policy_id(str): The identifier of the lifecycle policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dlm.lifecycle_policy.delete(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dlm.lifecycle_policy.delete policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dlm",
        operation="delete_lifecycle_policy",
        op_kwargs={"PolicyId": policy_id},
    )


async def get_all(
    hub,
    ctx,
    policy_ids: List = None,
    state: str = None,
    resource_types: List = None,
    target_tags: List = None,
    tags_to_add: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about all or the specified data lifecycle policies. To get complete information about a policy, use GetLifecyclePolicy.

    Args:
        policy_ids(List, optional): The identifiers of the data lifecycle policies. Defaults to None.
        state(str, optional): The activation state. Defaults to None.
        resource_types(List, optional): The resource type. Defaults to None.
        target_tags(List, optional): The target tag for a policy. Tags are strings in the format key=value. Defaults to None.
        tags_to_add(List, optional): The tags to add to objects created by the policy. Tags are strings in the format key=value. These user-defined tags are added in addition to the AWS-added lifecycle tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dlm.lifecycle_policy.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dlm.lifecycle_policy.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dlm",
        operation="get_lifecycle_policies",
        op_kwargs={
            "PolicyIds": policy_ids,
            "State": state,
            "ResourceTypes": resource_types,
            "TargetTags": target_tags,
            "TagsToAdd": tags_to_add,
        },
    )


async def get(hub, ctx, policy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets detailed information about the specified lifecycle policy.

    Args:
        policy_id(str): The identifier of the lifecycle policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dlm.lifecycle_policy.get(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dlm.lifecycle_policy.get policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dlm",
        operation="get_lifecycle_policy",
        op_kwargs={"PolicyId": policy_id},
    )


async def update(
    hub,
    ctx,
    policy_id: str,
    execution_role_arn: str = None,
    state: str = None,
    description: str = None,
    policy_details: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified lifecycle policy.

    Args:
        policy_id(str): The identifier of the lifecycle policy.
        execution_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role used to run the operations specified by the lifecycle policy. Defaults to None.
        state(str, optional): The desired activation state of the lifecycle policy after creation. Defaults to None.
        description(str, optional): A description of the lifecycle policy. Defaults to None.
        policy_details(Dict, optional): The configuration of the lifecycle policy. You cannot update the policy type or the resource type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dlm.lifecycle_policy.update(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dlm.lifecycle_policy.update policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dlm",
        operation="update_lifecycle_policy",
        op_kwargs={
            "PolicyId": policy_id,
            "ExecutionRoleArn": execution_role_arn,
            "State": state,
            "Description": description,
            "PolicyDetails": policy_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the cross-origin resource sharing (CORS) configuration information that is set for the container. To use this operation, you must have permission to perform the MediaStore:DeleteCorsPolicy action. The container owner has this permission by default and can grant this permission to others.

    Args:
        container_name(str): The name of the container to remove the policy from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.cors_policy.delete(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.cors_policy.delete container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="delete_cors_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def get(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the cross-origin resource sharing (CORS) configuration information that is set for the container. To use this operation, you must have permission to perform the MediaStore:GetCorsPolicy action. By default, the container owner has this permission and can grant it to others.

    Args:
        container_name(str): The name of the container that the policy is assigned to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.cors_policy.get(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.cors_policy.get container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="get_cors_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def put(hub, ctx, container_name: str, cors_policy: List) -> Dict:
    r"""
    **Autogenerated function**

    Sets the cross-origin resource sharing (CORS) configuration on a container so that the container can service cross-origin requests. For example, you might want to enable a request whose origin is http://www.example.com to access your AWS Elemental MediaStore container at my.example.container.com by using the browser's XMLHttpRequest capability. To enable CORS on a container, you attach a CORS policy to the container. In the CORS policy, you configure rules that identify origins and the HTTP methods that can be executed on your container. The policy can contain up to 398,000 characters. You can add up to 100 rules to a CORS policy. If more than one rule applies, the service uses the first applicable rule listed. To learn more about CORS, see Cross-Origin Resource Sharing (CORS) in AWS Elemental MediaStore.

    Args:
        container_name(str): The name of the container that you want to assign the CORS policy to.
        cors_policy(List): The CORS policy to apply to the container. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.cors_policy.put(
                ctx, container_name=value, cors_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.cors_policy.put container_name=value, cors_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="put_cors_policy",
        op_kwargs={"ContainerName": container_name, "CorsPolicy": cors_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, report_group_arns: List) -> Dict:
    r"""
    **Autogenerated function**

     Returns an array of report groups.

    Args:
        report_group_arns(List):  An array of report group ARNs that identify the report groups to return. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.get.report.group.batch(ctx, report_group_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.get.report.group.batch report_group_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="batch_get_report_groups",
        op_kwargs={"reportGroupArns": report_group_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, text: str) -> Dict:
    r"""
    **Autogenerated function**

    Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information. Amazon Comprehend Medical only detects medical entities in English language texts. The DetectEntitiesV2 operation replaces the DetectEntities operation. This new action uses a different model for determining the entities in your medical text and changes the way that some entities are returned in the output. You should use the DetectEntitiesV2 operation in all new applications. The DetectEntitiesV2 operation returns the Acuity and Direction entities as attributes instead of types.

    Args:
        text(str): A UTF-8 string containing the clinical content being examined for entities. Each string must contain fewer than 20,000 bytes of characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.entity.v2.detect(ctx, text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.entity.v2.detect text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="detect_entities_v2",
        op_kwargs={"Text": text},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def remove(
    hub, ctx, application_id: str, attribute_type: str, update_attributes_request: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more attributes, of the same attribute type, from all the endpoints that are associated with an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        attribute_type(str):  The type of attribute or attributes to remove. Valid values are: endpoint-custom-attributes - Custom attributes that describe endpoints, such as the date when an associated user opted in or out of receiving communications from you through a specific type of channel. endpoint-metric-attributes - Custom metrics that your app reports to Amazon Pinpoint for endpoints, such as the number of app sessions or the number of items left in a cart. endpoint-user-attributes - Custom attributes that describe users, such as first name, last name, and age.
        update_attributes_request(Dict): Specifies one or more attributes to remove from all the endpoints that are associated with an application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.attribute.remove(
                ctx, application_id=value, attribute_type=value, update_attributes_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.attribute.remove application_id=value, attribute_type=value, update_attributes_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="remove_attributes",
        op_kwargs={
            "ApplicationId": application_id,
            "AttributeType": attribute_type,
            "UpdateAttributesRequest": update_attributes_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    bucket_name: str,
    bundle_id: str,
    tags: List = None,
    enable_object_versioning: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Lightsail bucket. A bucket is a cloud storage resource available in the Lightsail object storage service. Use buckets to store objects such as data and its descriptive metadata. For more information about buckets, see Buckets in Amazon Lightsail in the Amazon Lightsail Developer Guide.

    Args:
        bucket_name(str): The name for the bucket. For more information about bucket names, see Bucket naming rules in Amazon Lightsail in the Amazon Lightsail Developer Guide.
        bundle_id(str): The ID of the bundle to use for the bucket. A bucket bundle specifies the monthly cost, storage space, and data transfer quota for a bucket. Use the GetBucketBundles action to get a list of bundle IDs that you can specify. Use the UpdateBucketBundle action to change the bundle after the bucket is created.
        tags(List, optional): The tag keys and optional values to add to the bucket during creation. Use the TagResource action to tag the bucket after it's created. Defaults to None.
        enable_object_versioning(bool, optional): A Boolean value that indicates whether to enable versioning of objects in the bucket. For more information about versioning, see Enabling and suspending bucket object versioning in Amazon Lightsail in the Amazon Lightsail Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.init.create(
                ctx, bucket_name=value, bundle_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.init.create bucket_name=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_bucket",
        op_kwargs={
            "bucketName": bucket_name,
            "bundleId": bundle_id,
            "tags": tags,
            "enableObjectVersioning": enable_object_versioning,
        },
    )


async def delete(hub, ctx, bucket_name: str, force_delete: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Amazon Lightsail bucket.  When you delete your bucket, the bucket name is released and can be reused for a new bucket in your account or another AWS account.

    Args:
        bucket_name(str): The name of the bucket to delete. Use the GetBuckets action to get a list of bucket names that you can specify.
        force_delete(bool, optional): A Boolean value that indicates whether to force delete the bucket. You must force delete the bucket if it has one of the following conditions:   The bucket is the origin of a distribution.   The bucket has instances that were granted access to it using the SetResourceAccessForBucket action.   The bucket has objects.   The bucket has access keys.    Force deleting a bucket might impact other resources that rely on the bucket, such as instances, distributions, or software that use the issued access keys. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.init.delete(ctx, bucket_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.init.delete bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_bucket",
        op_kwargs={"bucketName": bucket_name, "forceDelete": force_delete},
    )


async def get_all(
    hub,
    ctx,
    bucket_name: str = None,
    page_token: str = None,
    include_connected_resources: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more Amazon Lightsail buckets. For more information about buckets, see Buckets in Amazon Lightsail in the Amazon Lightsail Developer Guide..

    Args:
        bucket_name(str, optional): The name of the bucket for which to return information. When omitted, the response includes all of your buckets in the AWS Region where the request is made. Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetBuckets request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.
        include_connected_resources(bool, optional): A Boolean value that indicates whether to include Lightsail instances that were given access to the bucket using the SetResourceAccessForBucket action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_buckets",
        op_kwargs={
            "bucketName": bucket_name,
            "pageToken": page_token,
            "includeConnectedResources": include_connected_resources,
        },
    )


async def update(
    hub,
    ctx,
    bucket_name: str,
    access_rules: Dict = None,
    versioning: str = None,
    readonly_access_accounts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Amazon Lightsail bucket. Use this action to update the configuration of an existing bucket, such as versioning, public accessibility, and the AWS accounts that can access the bucket.

    Args:
        bucket_name(str): The name of the bucket to update.
        access_rules(Dict, optional): An object that sets the public accessibility of objects in the specified bucket. Defaults to None.
        versioning(str, optional): Specifies whether to enable or suspend versioning of objects in the bucket. The following options can be specified:    Enabled - Enables versioning of objects in the specified bucket.    Suspended - Suspends versioning of objects in the specified bucket. Existing object versions are retained.  . Defaults to None.
        readonly_access_accounts(List, optional): An array of strings to specify the AWS account IDs that can access the bucket. You can give a maximum of 10 AWS accounts access to a bucket. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.init.update(ctx, bucket_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.init.update bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_bucket",
        op_kwargs={
            "bucketName": bucket_name,
            "accessRules": access_rules,
            "versioning": versioning,
            "readonlyAccessAccounts": readonly_access_accounts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    bucket: str,
    key: str,
    version_id: str = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets an object's current Legal Hold status. For more information, see Locking Objects. This action is not supported by Amazon S3 on Outposts.

    Args:
        bucket(str): The bucket name containing the object whose Legal Hold status you want to retrieve.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        key(str): The key name for the object whose Legal Hold status you want to retrieve.
        version_id(str, optional): The version ID of the object whose Legal Hold status you want to retrieve. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.legal_hold.get(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.legal_hold.get bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_object_legal_hold",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "VersionId": version_id,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    key: str,
    legal_hold: Dict = None,
    request_payer: str = None,
    version_id: str = None,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a Legal Hold configuration to the specified object. For more information, see Locking Objects. This action is not supported by Amazon S3 on Outposts.

    Args:
        bucket(str): The bucket name containing the object that you want to place a Legal Hold on.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        key(str): The key name for the object that you want to place a Legal Hold on.
        legal_hold(Dict, optional): Container element for the Legal Hold configuration you want to apply to the specified object. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        version_id(str, optional): The version ID of the object that you want to place a Legal Hold on. Defaults to None.
        content_md5(str, optional): The MD5 hash for the request body. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.legal_hold.put(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.legal_hold.put bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_object_legal_hold",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "LegalHold": legal_hold,
            "RequestPayer": request_payer,
            "VersionId": version_id,
            "ContentMD5": content_md5,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_name: str,
    dataset_name: str,
    client_token: str,
    dataset_schema: Dict = None,
    labels_input_configuration: Dict = None,
    training_data_start_time: str = None,
    training_data_end_time: str = None,
    evaluation_data_start_time: str = None,
    evaluation_data_end_time: str = None,
    role_arn: str = None,
    data_pre_processing_configuration: Dict = None,
    server_side_kms_key_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an ML model for data inference.  A machine-learning (ML) model is a mathematical model that finds patterns in your data. In Amazon Lookout for Equipment, the model learns the patterns of normal behavior and detects abnormal behavior that could be potential equipment failure (or maintenance events). The models are made by analyzing normal data and abnormalities in machine behavior that have already occurred. Your model is trained using a portion of the data from your dataset and uses that data to learn patterns of normal behavior and abnormal patterns that lead to equipment failure. Another portion of the data is used to evaluate the model's accuracy.

    Args:
        model_name(str): The name for the ML model to be created.
        dataset_name(str): The name of the dataset for the ML model being created. .
        dataset_schema(Dict, optional): The data schema for the ML model being created. . Defaults to None.
        labels_input_configuration(Dict, optional): The input configuration for the labels being used for the ML model that's being created. . Defaults to None.
        client_token(str): A unique identifier for the request. If you do not set the client request token, Amazon Lookout for Equipment generates one. .
        training_data_start_time(str, optional): Indicates the time reference in the dataset that should be used to begin the subset of training data for the ML model. . Defaults to None.
        training_data_end_time(str, optional): Indicates the time reference in the dataset that should be used to end the subset of training data for the ML model. . Defaults to None.
        evaluation_data_start_time(str, optional): Indicates the time reference in the dataset that should be used to begin the subset of evaluation data for the ML model. . Defaults to None.
        evaluation_data_end_time(str, optional):  Indicates the time reference in the dataset that should be used to end the subset of evaluation data for the ML model. . Defaults to None.
        role_arn(str, optional):  The Amazon Resource Name (ARN) of a role with permission to access the data source being used to create the ML model. . Defaults to None.
        data_pre_processing_configuration(Dict, optional): The configuration is the TargetSamplingRate, which is the sampling rate of the data after post processing by Amazon Lookout for Equipment. For example, if you provide data that has been collected at a 1 second level and you want the system to resample the data at a 1 minute rate before training, the TargetSamplingRate is 1 minute. When providing a value for the TargetSamplingRate, you must attach the prefix "PT" to the rate you want. The value for a 1 second rate is therefore PT1S, the value for a 15 minute rate is PT15M, and the value for a 1 hour rate is PT1H . Defaults to None.
        server_side_kms_key_id(str, optional): Provides the identifier of the AWS KMS customer master key (CMK) used to encrypt model data by Amazon Lookout for Equipment. . Defaults to None.
        tags(List, optional):  Any tags associated with the ML model being created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.model.create(
                ctx, model_name=value, dataset_name=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.model.create model_name=value, dataset_name=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="create_model",
        op_kwargs={
            "ModelName": model_name,
            "DatasetName": dataset_name,
            "DatasetSchema": dataset_schema,
            "LabelsInputConfiguration": labels_input_configuration,
            "ClientToken": client_token,
            "TrainingDataStartTime": training_data_start_time,
            "TrainingDataEndTime": training_data_end_time,
            "EvaluationDataStartTime": evaluation_data_start_time,
            "EvaluationDataEndTime": evaluation_data_end_time,
            "RoleArn": role_arn,
            "DataPreProcessingConfiguration": data_pre_processing_configuration,
            "ServerSideKmsKeyId": server_side_kms_key_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, model_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an ML model currently available for Amazon Lookout for Equipment. This will prevent it from being used with an inference scheduler, even one that is already set up.

    Args:
        model_name(str): The name of the ML model to be deleted. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.model.delete(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.model.delete model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="delete_model",
        op_kwargs={"ModelName": model_name},
    )


async def describe(hub, ctx, model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides overall information about a specific ML model, including model name and ARN, dataset, training and evaluation information, status, and so on.

    Args:
        model_name(str): The name of the ML model to be described. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.model.describe(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.model.describe model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="describe_model",
        op_kwargs={"ModelName": model_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    status: str = None,
    model_name_begins_with: str = None,
    dataset_name_begins_with: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a list of all models in the account, including model name and ARN, dataset, and status.

    Args:
        next_token(str, optional):  An opaque pagination token indicating where to continue the listing of ML models. . Defaults to None.
        max_results(int, optional):  Specifies the maximum number of ML models to list. . Defaults to None.
        status(str, optional): The status of the ML model. . Defaults to None.
        model_name_begins_with(str, optional): The beginning of the name of the ML models being listed. . Defaults to None.
        dataset_name_begins_with(str, optional): The beginning of the name of the dataset of the ML models to be listed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.model.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.model.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="list_models",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Status": status,
            "ModelNameBeginsWith": model_name_begins_with,
            "DatasetNameBeginsWith": dataset_name_begins_with,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, volume_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists iSCSI initiators that are connected to a volume. You can use this operation to determine whether a volume is being used or not. This operation is only supported in the cached volume and stored volume gateway types.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes for the gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.initiator.list_all(ctx, volume_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.initiator.list_all volume_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_volume_initiators",
        op_kwargs={"VolumeARN": volume_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    event_type_ids: List,
    resource: str,
    targets: List,
    detail_type: str,
    client_request_token: str = None,
    tags: Dict = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a notification rule for a resource. The rule specifies the events you want notifications about and the targets (such as SNS topics) where you want to receive them.

    Args:
        name(str): The name for the notification rule. Notifictaion rule names must be unique in your AWS account.
        event_type_ids(List): A list of event types associated with this notification rule. For a list of allowed events, see EventTypeSummary.
        resource(str): The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline, repositories in AWS CodeCommit, and build projects in AWS CodeBuild.
        targets(List): A list of Amazon Resource Names (ARNs) of SNS topics to associate with the notification rule.
        detail_type(str): The level of detail to include in the notifications for this resource. BASIC will include only the contents of the event as it would appear in AWS CloudWatch. FULL will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
        client_request_token(str, optional): A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request with the same parameters is received and a token is included, the request returns information about the initial request that used that token.  The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you. . Defaults to None.
        tags(Dict, optional): A list of tags to apply to this notification rule. Key names cannot start with "aws". . Defaults to None.
        status(str, optional): The status of the notification rule. The default value is ENABLED. If the status is set to DISABLED, notifications aren't sent for the notification rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.notification_rule.create(
                ctx,
                name=value,
                event_type_ids=value,
                resource=value,
                targets=value,
                detail_type=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.notification_rule.create name=value, event_type_ids=value, resource=value, targets=value, detail_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="create_notification_rule",
        op_kwargs={
            "Name": name,
            "EventTypeIds": event_type_ids,
            "Resource": resource,
            "Targets": targets,
            "DetailType": detail_type,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
            "Status": status,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a notification rule for a resource.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.notification_rule.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.notification_rule.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="delete_notification_rule",
        op_kwargs={"Arn": arn},
    )


async def describe(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specified notification rule.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.notification_rule.describe(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.notification_rule.describe arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="describe_notification_rule",
        op_kwargs={"Arn": arn},
    )


async def list_all(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the notification rules for an AWS account.

    Args:
        filters(List, optional): The filters to use to return information by service or resource type. For valid values, see ListNotificationRulesFilter.  A filter with the same name can appear more than once when used with OR statements. Filters with different names should be applied with AND statements. . Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-negative integer used to limit the number of returned results. The maximum number of results that can be returned is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.notification_rule.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.notification_rule.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="list_notification_rules",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    status: str = None,
    event_type_ids: List = None,
    targets: List = None,
    detail_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a notification rule for a resource. You can change the events that trigger the notification rule, the status of the rule, and the targets that receive the notifications.  To add or remove tags for a notification rule, you must use TagResource and UntagResource.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule.
        name(str, optional): The name of the notification rule. Defaults to None.
        status(str, optional): The status of the notification rule. Valid statuses include enabled (sending notifications) or disabled (not sending notifications). Defaults to None.
        event_type_ids(List, optional): A list of event types associated with this notification rule. Defaults to None.
        targets(List, optional): The address and type of the targets to receive notifications from this notification rule. Defaults to None.
        detail_type(str, optional): The level of detail to include in the notifications for this resource. BASIC will include only the contents of the event as it would appear in AWS CloudWatch. FULL will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.notification_rule.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.notification_rule.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="update_notification_rule",
        op_kwargs={
            "Arn": arn,
            "Name": name,
            "Status": status,
            "EventTypeIds": event_type_ids,
            "Targets": targets,
            "DetailType": detail_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    association_id: str,
    execution_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Views information about a specific execution of a specific association.

    Args:
        association_id(str): The association ID that includes the execution for which you want to view details.
        execution_id(str): The execution ID for which you want to view details.
        filters(List, optional): Filters for the request. You can specify the following filters and values. Status (EQUAL) ResourceId (EQUAL) ResourceType (EQUAL). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.execution.target.describe_all(
                ctx, association_id=value, execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.execution.target.describe_all association_id=value, execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_association_execution_targets",
        op_kwargs={
            "AssociationId": association_id,
            "ExecutionId": execution_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a running query. To be canceled, a query must be running.

    Args:
        id_(str): The identifier of the SQL statement to cancel. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This identifier is returned by BatchExecuteStatment, ExecuteStatment, and ListStatements. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.statement.init.cancel(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.statement.init.cancel id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="cancel_statement",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the details about a specific instance when a query was run by the Amazon Redshift Data API. The information includes when the query started, when it finished, the query status, the number of rows returned, and the SQL statement.

    Args:
        id_(str): The identifier of the SQL statement to describe. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates the number of the SQL statement. For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a suffix of :2 that indicates the second SQL statement of a batch query. This identifier is returned by BatchExecuteStatment, ExecuteStatement, and ListStatements. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.statement.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.statement.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="describe_statement",
        op_kwargs={"Id": id_},
    )


async def execute(
    hub,
    ctx,
    cluster_identifier: str,
    database: str,
    sql: str,
    db_user: str = None,
    parameters: List = None,
    secret_arn: str = None,
    statement_name: str = None,
    with_event: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL). This statement must be a single SQL statement. Depending on the authorization method, use one of the following combinations of request parameters:    Secrets Manager - specify the Amazon Resource Name (ARN) of the secret, the database name, and the cluster identifier that matches the cluster in the secret.    Temporary credentials - specify the cluster identifier, the database name, and the database user name. Permission to call the redshift:GetClusterCredentials operation is required to use this method.

    Args:
        cluster_identifier(str): The cluster identifier. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        database(str): The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        db_user(str, optional): The database user name. This parameter is required when authenticating using temporary credentials. . Defaults to None.
        parameters(List, optional): The parameters for the SQL statement. Defaults to None.
        secret_arn(str, optional): The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager. . Defaults to None.
        sql(str): The SQL statement text to run. .
        statement_name(str, optional): The name of the SQL statement. You can name the SQL statement when you create it to identify the query. . Defaults to None.
        with_event(bool, optional): A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statement runs. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.statement.init.execute(
                ctx, cluster_identifier=value, database=value, sql=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.statement.init.execute cluster_identifier=value, database=value, sql=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="execute_statement",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Database": database,
            "DbUser": db_user,
            "Parameters": parameters,
            "SecretArn": secret_arn,
            "Sql": sql,
            "StatementName": statement_name,
            "WithEvent": with_event,
        },
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    role_level: bool = None,
    statement_name: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List of SQL statements. By default, only finished statements are shown. A token is returned to page through the statement list.

    Args:
        max_results(int, optional): The maximum number of SQL statements to return in the response. If more SQL statements exist than fit in one response, then NextToken is returned to page through the results. . Defaults to None.
        next_token(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. . Defaults to None.
        role_level(bool, optional): A value that filters which statements to return in the response. If true, all statements run by the caller's IAM role are returned. If false, only statements run by the caller's IAM role in the current IAM session are returned. The default is true. . Defaults to None.
        statement_name(str, optional): The name of the SQL statement specified as input to BatchExecuteStatement or ExecuteStatement to identify the query. You can list multiple statements by providing a prefix that matches the beginning of the statement name. For example, to list myStatement1, myStatement2, myStatement3, and so on, then provide the a value of myStatement. Data API does a case-sensitive match of SQL statement names to the prefix value you provide. . Defaults to None.
        status(str, optional): The status of the SQL statement to list. Status values are defined as follows:    ABORTED - The query run was stopped by the user.    ALL - A status value that includes all query statuses. This value can be used to filter results.    FAILED - The query run failed.    FINISHED - The query has finished running.    PICKED - The query has been chosen to be run.    STARTED - The query run has started.    SUBMITTED - The query was submitted, but not yet processed.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.statement.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.statement.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="list_statements",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "RoleLevel": role_level,
            "StatementName": statement_name,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(hub, ctx, marker: str = None, max_items: int = None) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns all the domain names registered with Amazon Route 53 for the current AWS account.

    Args:
        marker(str, optional): For an initial request for a list of domains, omit this element. If the number of domains that are associated with the current AWS account is greater than the value that you specified for MaxItems, you can use Marker to return additional domains. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element. Constraints: The marker must match the value specified in the previous request. Defaults to None.
        max_items(int, optional): Number of domains to be returned. Default: 20. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="list_domains",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def register(
    hub,
    ctx,
    domain_name: str,
    duration_in_years: int,
    admin_contact: Dict,
    registrant_contact: Dict,
    tech_contact: Dict,
    idn_lang_code: str = None,
    auto_renew: bool = None,
    privacy_protect_admin_contact: bool = None,
    privacy_protect_registrant_contact: bool = None,
    privacy_protect_tech_contact: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation registers a domain. Domains are registered either by Amazon Registrar (for .com, .net, and .org domains) or by our registrar associate, Gandi (for all other domains). For some top-level domains (TLDs), this operation requires extra parameters. When you register a domain, Amazon Route 53 does the following:   Creates a Route 53 hosted zone that has the same name as the domain. Route 53 assigns four name servers to your hosted zone and automatically updates your domain registration with the names of these name servers.   Enables autorenew, so your domain registration will renew automatically each year. We'll notify you in advance of the renewal date so you can choose whether to renew the registration.   Optionally enables privacy protection, so WHOIS queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you don't enable privacy protection, WHOIS queries return the information that you entered for the registrant, admin, and tech contacts.   If registration is successful, returns an operation ID that you can use to track the progress and completion of the action. If the request is not completed successfully, the domain registrant is notified by email.   Charges your AWS account an amount based on the top-level domain. For more information, see Amazon Route 53 Pricing.

    Args:
        domain_name(str): The domain name that you want to register. The top-level domain (TLD), such as .com, must be a TLD that Route 53 supports. For a list of supported TLDs, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. The domain name can contain only the following characters:   Letters a through z. Domain names are not case sensitive.   Numbers 0 through 9.   Hyphen (-). You can't specify a hyphen at the beginning or end of a label.    Period (.) to separate the labels in the name, such as the . in example.com.   Internationalized domain names are not supported for some top-level domains. To determine whether the TLD that you want to use supports internationalized domain names, see Domains that You Can Register with Amazon Route 53. For more information, see Formatting Internationalized Domain Names. .
        idn_lang_code(str, optional): Reserved for future use. Defaults to None.
        duration_in_years(int): The number of years that you want to register the domain for. Domains are registered for a minimum of one year. The maximum period depends on the top-level domain. For the range of valid values for your domain, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. Default: 1.
        auto_renew(bool, optional): Indicates whether the domain will be automatically renewed (true) or not (false). Autorenewal only takes effect after the account is charged. Default: true . Defaults to None.
        admin_contact(Dict): Provides detailed contact information. For information about the values that you specify for each element, see ContactDetail.
        registrant_contact(Dict): Provides detailed contact information. For information about the values that you specify for each element, see ContactDetail.
        tech_contact(Dict): Provides detailed contact information. For information about the values that you specify for each element, see ContactDetail.
        privacy_protect_admin_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the admin contact. Default: true . Defaults to None.
        privacy_protect_registrant_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the registrant contact (the domain owner). Default: true . Defaults to None.
        privacy_protect_tech_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the technical contact. Default: true . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.init.register(
                ctx,
                domain_name=value,
                duration_in_years=value,
                admin_contact=value,
                registrant_contact=value,
                tech_contact=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.init.register domain_name=value, duration_in_years=value, admin_contact=value, registrant_contact=value, tech_contact=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="register_domain",
        op_kwargs={
            "DomainName": domain_name,
            "IdnLangCode": idn_lang_code,
            "DurationInYears": duration_in_years,
            "AutoRenew": auto_renew,
            "AdminContact": admin_contact,
            "RegistrantContact": registrant_contact,
            "TechContact": tech_contact,
            "PrivacyProtectAdminContact": privacy_protect_admin_contact,
            "PrivacyProtectRegistrantContact": privacy_protect_registrant_contact,
            "PrivacyProtectTechContact": privacy_protect_tech_contact,
        },
    )


async def renew(
    hub, ctx, domain_name: str, current_expiry_year: int, duration_in_years: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation renews a domain for the specified number of years. The cost of renewing your domain is billed to your AWS account. We recommend that you renew your domain several weeks before the expiration date. Some TLD registries delete domains before the expiration date if you haven't renewed far enough in advance. For more information about renewing domain registration, see Renewing Registration for a Domain in the Amazon Route 53 Developer Guide.

    Args:
        domain_name(str): The name of the domain that you want to renew.
        duration_in_years(int, optional): The number of years that you want to renew the domain for. The maximum number of years depends on the top-level domain. For the range of valid values for your domain, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. Default: 1. Defaults to None.
        current_expiry_year(int): The year when the registration for the domain is set to expire. This value must match the current expiration date for the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.init.renew(
                ctx, domain_name=value, current_expiry_year=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.init.renew domain_name=value, current_expiry_year=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="renew_domain",
        op_kwargs={
            "DomainName": domain_name,
            "DurationInYears": duration_in_years,
            "CurrentExpiryYear": current_expiry_year,
        },
    )


async def transfer(
    hub,
    ctx,
    domain_name: str,
    duration_in_years: int,
    admin_contact: Dict,
    registrant_contact: Dict,
    tech_contact: Dict,
    idn_lang_code: str = None,
    nameservers: List = None,
    auth_code: str = None,
    auto_renew: bool = None,
    privacy_protect_admin_contact: bool = None,
    privacy_protect_registrant_contact: bool = None,
    privacy_protect_tech_contact: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Transfers a domain from another registrar to Amazon Route 53. When the transfer is complete, the domain is registered either with Amazon Registrar (for .com, .net, and .org domains) or with our registrar associate, Gandi (for all other TLDs). For more information about transferring domains, see the following topics:   For transfer requirements, a detailed procedure, and information about viewing the status of a domain that you're transferring to Route 53, see Transferring Registration for a Domain to Amazon Route 53 in the Amazon Route 53 Developer Guide.   For information about how to transfer a domain from one AWS account to another, see TransferDomainToAnotherAwsAccount.    For information about how to transfer a domain to another domain registrar, see Transferring a Domain from Amazon Route 53 to Another Registrar in the Amazon Route 53 Developer Guide.   If the registrar for your domain is also the DNS service provider for the domain, we highly recommend that you transfer your DNS service to Route 53 or to another DNS service provider before you transfer your registration. Some registrars provide free DNS service when you purchase a domain registration. When you transfer the registration, the previous registrar will not renew your domain registration and could end your DNS service at any time.  If the registrar for your domain is also the DNS service provider for the domain and you don't transfer DNS service to another provider, your website, email, and the web applications associated with the domain might become unavailable.  If the transfer is successful, this method returns an operation ID that you can use to track the progress and completion of the action. If the transfer doesn't complete successfully, the domain registrant will be notified by email.

    Args:
        domain_name(str): The name of the domain that you want to transfer to Route 53. The top-level domain (TLD), such as .com, must be a TLD that Route 53 supports. For a list of supported TLDs, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. The domain name can contain only the following characters:   Letters a through z. Domain names are not case sensitive.   Numbers 0 through 9.   Hyphen (-). You can't specify a hyphen at the beginning or end of a label.    Period (.) to separate the labels in the name, such as the . in example.com.  .
        idn_lang_code(str, optional): Reserved for future use. Defaults to None.
        duration_in_years(int): The number of years that you want to register the domain for. Domains are registered for a minimum of one year. The maximum period depends on the top-level domain. Default: 1.
        nameservers(List, optional): Contains details for the host and glue IP addresses. Defaults to None.
        auth_code(str, optional): The authorization code for the domain. You get this value from the current registrar. Defaults to None.
        auto_renew(bool, optional): Indicates whether the domain will be automatically renewed (true) or not (false). Autorenewal only takes effect after the account is charged. Default: true. Defaults to None.
        admin_contact(Dict): Provides detailed contact information.
        registrant_contact(Dict): Provides detailed contact information.
        tech_contact(Dict): Provides detailed contact information.
        privacy_protect_admin_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the admin contact. Default: true . Defaults to None.
        privacy_protect_registrant_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the registrant contact (domain owner). Default: true . Defaults to None.
        privacy_protect_tech_contact(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the technical contact. Default: true . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.init.transfer(
                ctx,
                domain_name=value,
                duration_in_years=value,
                admin_contact=value,
                registrant_contact=value,
                tech_contact=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.init.transfer domain_name=value, duration_in_years=value, admin_contact=value, registrant_contact=value, tech_contact=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="transfer_domain",
        op_kwargs={
            "DomainName": domain_name,
            "IdnLangCode": idn_lang_code,
            "DurationInYears": duration_in_years,
            "Nameservers": nameservers,
            "AuthCode": auth_code,
            "AutoRenew": auto_renew,
            "AdminContact": admin_contact,
            "RegistrantContact": registrant_contact,
            "TechContact": tech_contact,
            "PrivacyProtectAdminContact": privacy_protect_admin_contact,
            "PrivacyProtectRegistrantContact": privacy_protect_registrant_contact,
            "PrivacyProtectTechContact": privacy_protect_tech_contact,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def finalize(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Finalizes the cutover immediately for specific Source Servers. All AWS resources created by Application Migration Service for enabling the replication of these source servers will be terminated / deleted within 90 minutes. Launched Test or Cutover instances will NOT be terminated. The AWS Replication Agent will receive a command to uninstall itself (within 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be to DISCONNECTED; The SourceServer.lifeCycle.state will be changed to CUTOVER; The totalStorageBytes property fo each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDurationwill be nullified.

    Args:
        source_server_id(str): Request to finalize Cutover by Soure Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.cutover.finalize(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.cutover.finalize source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="finalize_cutover",
        op_kwargs={"sourceServerID": source_server_id},
    )


async def start(hub, ctx, source_server_i_ds: List, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Launches a Cutover Instance for specific Source Servers. This command starts a LAUNCH job whose initiatedBy property is StartCutover and changes the SourceServer.lifeCycle.state property to CUTTING_OVER.

    Args:
        source_server_i_ds(List): Start Cutover by Source Server IDs.
        tags(Dict, optional): Start Cutover by Tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.cutover.start(ctx, source_server_i_ds=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.cutover.start source_server_i_ds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="start_cutover",
        op_kwargs={"sourceServerIDs": source_server_i_ds, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    organization_entity_filters: List,
    locale: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in AWS Organizations, based on the filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the AWS service. At least one event Amazon Resource Name (ARN) and account ID are required. Results are sorted by the lastUpdatedTime of the entity, starting with the most recent. Before you can call this operation, you must first enable AWS Health to work with AWS Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.    This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.   This operation doesn't support resource-level permissions. You can't use this operation to allow or deny access to specific AWS Health events. For more information, see Resource- and action-based conditions in the AWS Health User Guide.

    Args:
        organization_entity_filters(List): A JSON set of elements including the awsAccountId and the eventArn.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.affected.entity.for_organization.describe(
                ctx, organization_entity_filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.affected.entity.for_organization.describe organization_entity_filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_affected_entities_for_organization",
        op_kwargs={
            "organizationEntityFilters": organization_entity_filters,
            "locale": locale,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the versioning state of a bucket. To retrieve the versioning state of a bucket, you must be the bucket owner. This implementation also returns the MFA Delete status of the versioning state. If the MFA Delete status is enabled, the bucket owner must use an authentication device to change the versioning state of the bucket. The following operations are related to GetBucketVersioning:    GetObject     PutObject     DeleteObject

    Args:
        bucket(str): The name of the bucket for which to get the versioning information.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.versioning.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.versioning.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_versioning",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    versioning_configuration: Dict,
    content_md5: str = None,
    mfa: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the versioning state of an existing bucket. To set the versioning state, you must be the bucket owner. You can set the versioning state with one of the following values:  Enabled—Enables versioning for the objects in the bucket. All objects added to the bucket receive a unique version ID.  Suspended—Disables versioning for the objects in the bucket. All objects added to the bucket receive the version ID null. If the versioning state has never been set on a bucket, it has no versioning state; a GetBucketVersioning request does not return a versioning state value. If the bucket owner enables MFA Delete in the bucket versioning configuration, the bucket owner must include the x-amz-mfa request header and the Status and the MfaDelete request elements in a request to set the versioning state of the bucket.  If you have an object expiration lifecycle policy in your non-versioned bucket and you want to maintain the same permanent delete behavior when you enable versioning, you must add a noncurrent expiration policy. The noncurrent expiration lifecycle policy will manage the deletes of the noncurrent object versions in the version-enabled bucket. (A version-enabled bucket maintains one current and zero or more noncurrent object versions.) For more information, see Lifecycle and Versioning.   Related Resources     CreateBucket     DeleteBucket     GetBucketVersioning

    Args:
        bucket(str): The bucket name.
        content_md5(str, optional): >The base64-encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        mfa(str, optional): The concatenation of the authentication device's serial number, a space, and the value that is displayed on your authentication device. Defaults to None.
        versioning_configuration(Dict): Container for setting the versioning state.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.versioning.put(
                ctx, bucket=value, versioning_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.versioning.put bucket=value, versioning_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_versioning",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "MFA": mfa,
            "VersioningConfiguration": versioning_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def describe(
    hub, ctx, instance_arn: str, account_assignment_creation_request_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the status of the assignment creation request.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        account_assignment_creation_request_id(str): The identifier that is used to track the request operation progress.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.assignment.creation_status.describe(
                ctx, instance_arn=value, account_assignment_creation_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.assignment.creation_status.describe instance_arn=value, account_assignment_creation_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="describe_account_assignment_creation_status",
        op_kwargs={
            "InstanceArn": instance_arn,
            "AccountAssignmentCreationRequestId": account_assignment_creation_request_id,
        },
    )


async def list_(
    hub,
    ctx,
    instance_arn: str,
    max_results: int = None,
    next_token: str = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the status of the Amazon Web Services account assignment creation requests for a specified SSO instance.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        max_results(int, optional): The maximum number of results to display for the assignment. Defaults to None.
        next_token(str, optional): The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. Defaults to None.
        filter_(Dict, optional): Filters results based on the passed attribute value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.assignment.creation_status.list(
                ctx, instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.assignment.creation_status.list instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="list_account_assignment_creation_status",
        op_kwargs={
            "InstanceArn": instance_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filter": filter_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    license_arn: str,
    client_token: str,
    role_arns: List = None,
    expiration_in_days: int = None,
    token_properties: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a long-lived token. A refresh token is a JWT token used to get an access token. With an access token, you can call AssumeRoleWithWebIdentity to get role credentials that you can use to call License Manager to manage the specified license.

    Args:
        license_arn(str): Amazon Resource Name (ARN) of the license. The ARN is mapped to the aud claim of the JWT token.
        role_arns(List, optional): Amazon Resource Name (ARN) of the IAM roles to embed in the token. License Manager does not check whether the roles are in use. Defaults to None.
        expiration_in_days(int, optional): Token expiration, in days, counted from token creation. The default is 365 days. Defaults to None.
        token_properties(List, optional): Data specified by the caller to be included in the JWT token. The data is mapped to the amr claim of the JWT token. Defaults to None.
        client_token(str): Idempotency token, valid for 10 minutes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.token.create(
                ctx, license_arn=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.token.create license_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="create_token",
        op_kwargs={
            "LicenseArn": license_arn,
            "RoleArns": role_arns,
            "ExpirationInDays": expiration_in_days,
            "TokenProperties": token_properties,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, token_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified token. Must be called in the license home Region.

    Args:
        token_id(str): Token ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.token.delete(ctx, token_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.token.delete token_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="delete_token",
        op_kwargs={"TokenId": token_id},
    )


async def list_all(
    hub,
    ctx,
    token_ids: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your tokens.

    Args:
        token_ids(List, optional): Token IDs. Defaults to None.
        filters(List, optional): Filters to scope the results. The following filter is supported:    LicenseArns   . Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.token.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.token.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_tokens",
        op_kwargs={
            "TokenIds": token_ids,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Assigns a set of key-value pairs to a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN).

    Args:
        resource_arn(str): An ARN that uniquely identifies a resource. The format of the ARN depends on the type of the tagged resource.
        tags(Dict): Key-value pairs that are used to help organize your resources. You can assign your own metadata to the resources you create.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_key_list: List) -> None:
    r"""
    **Autogenerated function**

    Removes a set of key-value pairs from a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)

    Args:
        resource_arn(str): An ARN that uniquely identifies a resource. The format of the ARN depends on the type of the tagged resource.
        tag_key_list(List): A list of keys to identify which key-value tags to remove from a resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.resource.untag(
                ctx, resource_arn=value, tag_key_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.resource.untag resource_arn=value, tag_key_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeyList": tag_key_list},
    )
